@@ -1,13 +1,10 @@
-from rest_framework.views import APIView
-
-from seahub.api2.utils import json_response, is_seafile_pro
+# Copyright (c) 2012-2016 Seafile Ltd.
+from seahub.api2.base import APIView
+from seahub.api2.utils import json_response
 from seahub import settings
-from seahub.utils import HAS_OFFICE_CONVERTER, HAS_FILE_SEARCH
-try:
-    from seahub.settings import DISABLE_SYNC_WITH_ANY_FOLDER
-except ImportError:
-    DISABLE_SYNC_WITH_ANY_FOLDER = False
+from seahub.utils import HAS_OFFICE_CONVERTER, HAS_FILE_SEARCH, is_pro_version
 
+from constance import config
 
 class ServerInfoView(APIView):
     """
@@ -17,11 +14,12 @@ class ServerInfoView(APIView):
     def get(self, request, format=None):
         info = {
             'version': settings.SEAFILE_VERSION,
+            'encrypted_library_version': settings.ENCRYPTED_LIBRARY_VERSION if settings.ENCRYPTED_LIBRARY_VERSION >= 3 else 2,
         }
 
         features = ['seafile-basic']
 
-        if is_seafile_pro():
+        if is_pro_version():
             features.append('seafile-pro')
 
         if HAS_OFFICE_CONVERTER:
@@ -30,7 +28,7 @@ class ServerInfoView(APIView):
         if HAS_FILE_SEARCH:
             features.append('file-search')
 
-        if DISABLE_SYNC_WITH_ANY_FOLDER:
+        if config.DISABLE_SYNC_WITH_ANY_FOLDER:
             features.append('disable-sync-with-any-folder')
 
         if hasattr(settings, 'DESKTOP_CUSTOM_LOGO'):
